# line 629 "/home/ollisg/dev/Alien-Build/lib/Test/Alien.pm"

            package Test::Alien::XS::Mod0;
          
            use strict;
            use warnings;
            require XSLoader;
            our $VERSION = '0.01';
            XSLoader::load('Test::Alien::XS::Mod0',$VERSION);
          
            1;
          